@@ -7,8 +7,8 @@ def logger(err_name):
 
             try:
                 result = func(*args, **kwargs)
-                log_step = {"step": func.__name__, "result": result, "exe_time": datetime.datetime}
-                print(log_step)
+                #log_step = {"step": func.__name__, "result": result, "exe_time": datetime.datetime}
+                #print(log_step)
                 return result
             except Exception as err:
                 desc = ""
